package cz.zcu.kiv.vsp.msloup.generator;

/**
 * Generator exponencialniho rozdeleni s parametrem lambda.<br>
 * <br>
 * Priklad pouziti:<br>
 * <br>
 * <pre><code> IGenerator gen = new ExponentialGenerator(1.3);
 * System.out.println(gen.nextValue()); // vypise vygenerovanou hodnotu</code></pre>
 *
 * @author Martin Sloup
 */
public class ExponentialGenerator implements IGenerator {
	private double lambda;

	/**
	 * Konstruktor generatoru exponencialniho rozdeleni s parametrem lambda
	 * @param lambda	parametr rozdeleni
	 */
	public ExponentialGenerator(double lambda) {
		//lambda musi byt kladna hodnota
		this.lambda = Math.abs(lambda);
	}

	/**
	 * Vygeneruje dalsi hodnotu exponencialniho rozdeleni a vrati ji.
	 * @return	vygenerovanou hodnotu
	 */
	@Override
	public double nextValue() {
		// generujeme cisla podle vzorce (inverzni distribucni funkce exponencialniho rozdeleni):
		// F^-1 (p) = -ln(1 - p) / lambda
		return -Math.log(1 - Math.random()) / lambda;
	}

}
