package cz.zcu.kiv.vsp.msloup.generator;

/**
 * Generator spojiteho rovnomerneho rozdeleni s parametrem a a b pro generovani cisel na intervalu <a,b>.<br>
 * <br>
 * Priklad pouziti:<br>
 * <br>
 * <pre><code> IGenerator gen = new UniformGenerator(0, 1);
 * System.out.println(gen.nextValue()); // vypise vygenerovanou hodnotu</code></pre>
 *
 * @author Martin Sloup
 */
public class UniformGenerator implements IGenerator {
	private double a;
	private double b;

	/**
	 * Konstruktor generatoru spojiteho rovnomerneho rozdeleni pro generovani cisel na intervalu <a,b>
	 * @param a		pocatek intervalu
	 * @param b		konec intervalu
	 */
	public UniformGenerator(double a, double b) {

		//osetreni prehozeni hodnot intervalu
		if (b < a)
			throw new IllegalArgumentException("Parametr a musi byt mensi nez parametr b.");

		this.a = a;
		this.b = b;
	}

	/**
	 * Vygeneruje dalsi hodnotu spojiteho rovnomerneho rozdeleni a vrati ji.
	 * @return	vygenerovanou hodnotu
	 */
	@Override
	public double nextValue() {
		double number = Math.random();

		//v polovine pripadu cislo odecteme od jednicky, cimz zajistime,
		//ze vygenerovane cislo bude v intervalu <0,1> misto puvodniho <0,1)
		//Zdroj JSimSystem.uniform(); trochu mensi inspirace
		if (Math.random() < 0.5)
			number = 1 - number;

		return (number * (b - a)) + a;
	}

}
