package cz.zcu.kiv.vsp.msloup.object;

import java.util.TreeMap;

import cz.zcu.kiv.vsp.msloup.generator.IGenerator;
import cz.zcu.kiv.vsp.msloup.generator.UniformGenerator;
import cz.zcu.kiv.vsp.msloup.request.IRequest;
import cz.zcu.kiv.vsp.msloup.request.IRequestInput;

/**
 * Trida vytvarejici volby cile pozadavku na zaklade pravdepodobnosti
 * @author Martin Sloup
 *
 */
public class Choice implements IRequestInput {
	private TreeMap<Double, IRequestInput> choiceMap;
	private double currentMaxProbably = 0;
	private IGenerator generator;

	/**
	 * Konstruktor tridy pro vytvoreni volby cile pozadavku na zaklade pravdepodobnosti
	 */
	public Choice() {
		choiceMap = new TreeMap<Double, IRequestInput>();

		generator = new UniformGenerator(0, 1);
	}

	/**
	 * Prida volbu presmerovani pozadavku na zaklade pravdepodobnosti 1 - p
	 * @param destination	cil presmerovani
	 * @return referenci tridy
	 */
	public Choice addChoice(IRequestInput destination) {
		return addChoice(1 - currentMaxProbably, destination);
	}

	/**
	 * Prida volbu presmerovani pozadavku na zaklade pravdepodobnosti
	 * @param probably		pravdepodobnost presmerovani pozadavku
	 * @param destination	cil presmerovani
	 * @return referenci tridy
	 */
	public Choice addChoice(double probably, IRequestInput destination) {
		currentMaxProbably+= probably;

		if (probably < 0 || probably > 1)
			throw new IllegalArgumentException("Zadana pravdepodobnost musi byt v rozsahu <0,1>.");

		if (currentMaxProbably > 1)
			throw new IllegalArgumentException("Celkova pravdepodobnost musi byt mensi nebo rovna 1.");

		choiceMap.put(currentMaxProbably, destination);

		return this;
	}

	/**
	 * Prijme pozadavek v simulaci a dle pravdepodobnosti ho preda dal
	 * @param request	pozadavek v simulaci
	 */
	@Override
	public void receiveRequest(IRequest request) {
		Double latesProbability = new Double(0);

		double number = generator.nextValue();

		if (choiceMap.isEmpty())
			return;

		// vybereme dle pravdepodobnosti prislusnou volbu a predame pozadavek
		for (Double probability: choiceMap.keySet()) {
			latesProbability = probability;

			if (number <= latesProbability) {
				choiceMap.get(probability).receiveRequest(request);
				return;
			}
		}

		// osetrime volbu, pokud posledni ma pravdepodobnost mensi nez 1
		choiceMap.get(latesProbability).receiveRequest(request);
	}
}
